aboutsummaryrefslogtreecommitdiff
path: root/video/codecs/msrle.cpp
diff options
context:
space:
mode:
authorEugene Sandulenko2011-01-23 19:08:09 +0000
committerEugene Sandulenko2011-01-23 19:08:09 +0000
commitcaa6684752a310e916b179125a4125a8b3be36f0 (patch)
treedc364d58619b297194bc5d0673b694c34fb51b6c /video/codecs/msrle.cpp
parent3d15871ee2d6a9c0ce4819a6ab5925638bafa8b9 (diff)
downloadscummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.gz
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.tar.bz2
scummvm-rg350-caa6684752a310e916b179125a4125a8b3be36f0.zip
VIDEO: Move video classes to Video:: namespace
svn-id: r55479
Diffstat (limited to 'video/codecs/msrle.cpp')
-rw-r--r--video/codecs/msrle.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/video/codecs/msrle.cpp b/video/codecs/msrle.cpp
index 556f0ee670..46158c49d7 100644
--- a/video/codecs/msrle.cpp
+++ b/video/codecs/msrle.cpp
@@ -28,7 +28,7 @@
#include "video/codecs/msrle.h"
#include "common/stream.h"
-namespace Graphics {
+namespace Video {
MSRLEDecoder::MSRLEDecoder(uint16 width, uint16 height, byte bitsPerPixel) {
_surface = new Graphics::Surface();
@@ -41,7 +41,7 @@ MSRLEDecoder::~MSRLEDecoder() {
delete _surface;
}
-const Surface *MSRLEDecoder::decodeImage(Common::SeekableReadStream *stream) {
+const Graphics::Surface *MSRLEDecoder::decodeImage(Common::SeekableReadStream *stream) {
if (_bitsPerPixel == 8) {
decode8(stream);
} else
@@ -75,7 +75,7 @@ void MSRLEDecoder::decode8(Common::SeekableReadStream *stream) {
output = data + (y * width);
if (y < 0) {
- warning("Next line is beyond picture bounds");
+ warning("MS RLE Codec: Next line is beyond picture bounds");
return;
}
@@ -93,7 +93,7 @@ void MSRLEDecoder::decode8(Common::SeekableReadStream *stream) {
x += count;
if (y < 0) {
- warning("Skip beyond picture bounds");
+ warning("MS RLE Codec: Skip beyond picture bounds");
return;
}
@@ -128,7 +128,7 @@ void MSRLEDecoder::decode8(Common::SeekableReadStream *stream) {
}
- warning("No end-of-picture code");
+ warning("MS RLE Codec: No end-of-picture code");
}
-} // End of namespace Graphics
+} // End of namespace Video